@@ -1,4 +1,4 @@
-/* Copyright (c) 2000-2007 Wolfgang Hoermann and Josef Leydold */
+/* Copyright (c) 2000-2008 Wolfgang Hoermann and Josef Leydold */
 /* Department of Statistics and Mathematics, WU Wien, Austria  */
 
 #include <unur_source.h>
@@ -19,6 +19,9 @@ static double _unur_empl_sample( struct unur_gen *gen );
 #ifdef UNUR_ENABLE_LOGGING
 static void _unur_empl_debug_init( const struct unur_gen *gen );
 #endif
+#ifdef UNUR_ENABLE_INFO
+static void _unur_empl_info( struct unur_gen *gen, int help );
+#endif
 #define DISTR_IN  distr->data.cemp      
 #define PAR       ((struct unur_empl_par*)par->datap) 
 #define GEN       ((struct unur_empl_gen*)gen->datap) 
@@ -87,6 +90,9 @@ _unur_empl_create( struct unur_par *par )
   gen->clone = _unur_empl_clone;
   GEN->observ   = DISTR.sample;          
   GEN->n_observ = DISTR.n_sample;        
+#ifdef UNUR_ENABLE_INFO
+  gen->info = _unur_empl_info;
+#endif
   return gen;
 } 
 struct unur_gen *
@@ -139,3 +145,21 @@ _unur_empl_debug_init( const struct unur_gen *gen )
   fprintf(log,"%s:\n",gen->genid);
 } 
 #endif   
+#ifdef UNUR_ENABLE_INFO
+void
+_unur_empl_info( struct unur_gen *gen, int help )
+{
+  struct unur_string *info = gen->infostr;
+  _unur_string_append(info,"generator ID: %s\n\n", gen->genid);
+  _unur_string_append(info,"distribution:\n");
+  _unur_distr_info_typename(gen);
+  _unur_string_append(info,"   functions = DATA  [length=%d]\n", GEN->n_observ);
+  _unur_string_append(info,"\n");
+  _unur_string_append(info,"method: EMPL (EMPirical distribution with Linear interpolation)\n");
+  _unur_string_append(info,"\n");
+  if (help) {
+    _unur_string_append(info,"parameters: none\n");
+    _unur_string_append(info,"\n");
+  }
+} 
+#endif   
