@@ -144,13 +144,13 @@ struct symbols {
 };
 #ifdef PARSER
 #  define S(name,type,priority,value,funct,deriv) \
-   (name),(type),(priority),(value),(funct),(deriv)
+   name,type,priority,value,funct,deriv
 #else
 #  define S(name,type,priority,value,funct,deriv) \
-   (name),
+   name,
 #endif
 #ifdef CODEGEN
-#  define CG(cc,fortran,java)  (cc),(fortran),(java)
+#  define CG(cc,fortran,java)  cc,fortran,java
 #else
 #  define CG(cc,fortran,java)
 #endif
