@@ -29,12 +29,14 @@
 #define CK_HRD_GEN       0x00100041u
 #define CK_HRI_PAR       0x00100050u
 #define CK_HRI_GEN       0x00100051u
+#define CK_ITDR_PAR      0x00100080u
+#define CK_ITDR_GEN      0x00100081u
 #define CK_NINV_PAR      0x00100060u
 #define CK_NINV_GEN      0x00100061u
 #define CK_NROU_PAR      0x00100070u
 #define CK_NROU_GEN      0x00100071u
-#define CK_ITDR_PAR      0x00100080u
-#define CK_ITDR_GEN      0x00100081u
+#define CK_PINV_PAR     0x00100130u
+#define CK_PINV_GEN     0x00100131u
 #define CK_SROU_PAR      0x00100090u
 #define CK_SROU_GEN      0x00100091u
 #define CK_SSR_PAR       0x001000a0u
